Welcome to pySciSci’s documentation! — pySciSci 0.6 documentation

# Welcome to pySciSci’s documentation!

## Table of Contents

- About
  - Funding
- Installation
- Examples
  - Getting Started Examples
  - Method Examples
  - Advanced Functionality
  - Science of Science Textbook
- The DataBase
  - Basic Data WorkFlow
  - DataSet Examples
  - DataFrames
  - Filters
  - Property Dictionaries
  - BibDataBase
  - OpenAlex
  - Microsoft Academic Graph (MAG)
  - Web of Science (WoS)
  - DBLP Computer Science Bibliography (DBLP)
  - American Physics Society (APS)
  - PubMed
  - Custom DB
- Bibliometrics
  - Publications and Citations
  - Author-centric Methods
- Biblio-Networks
  - `coauthorship_network()`
  - `cocitation_network()`
  - `cociting_network()`
  - `estimate_resolution()`
  - `extract_multiscale_backbone()`
- General Functions
  - `download_file_from_google_drive()`
  - `empty_mode()`
  - `groupby_count()`
  - `groupby_mean()`
  - `groupby_range()`
  - `groupby_total()`
  - `groupby_zero_col()`
  - `holder_mean()`
  - `isin_range()`
  - `isin_sorted()`
  - `jenson_shannon()`
  - `kl()`
  - `rank_array()`
  - `shannon_entropy()`
  - `simpson()`
  - `simpson_finite()`
  - `uniquemap_by_frequency()`
  - `value_to_int()`
  - `welford_mean_m2()`

## References

[1]

Santo Fortunato, Carl T. Bergstrom, Katy Borner, James A. Evans, Dirk Helbing, Staša Milojevic, Alexander M. Petersen, Filippo Radicchi, Roberta Sinatra, Brian Uzzi, Alessandro Vespignani, Ludo Waltman, Dashun Wang, and Albert-László Barabási. Science of science. Science, 359(6379):eaao0185, Mar 2018.

[2]

Dashun Wang and Albert-László Barabási. Science of Science. Cambridge University press, 2021.

[3]

Dashun Wang, Chaoming Song, and Albert-László -. L. Barabási. Quantifying long-term scientific impact. Science, 342(6154):127–132, 2013.

[4]

B. Uzzi, S. Mukherjee, M. Stringer, and B. Jones. Atypical combinations and scientific impact. Science, 342(6157):468–472, Oct 2013. doi:10.1126/science.1240474.

[5]

Jorge E Hirsch. An index to quantify an individual's scientific research output. Proceedings of the National academy of Sciences, 102(46):16569–16572, 2005.

[6]

Samuel F Way, Allison C Morgan, Aaron Clauset, and Daniel B Larremore. The misleading narrative of the canonical faculty productivity trajectory. Proceedings of the National Academy of Sciences, 114(44):E9216–E9223, 2017.

[7]

Nees Jan van Eck and Ludo Waltman. Generalizing the h-and g-indices. Journal of Informetrics, 2(4):263–271, 2008.